@@ -223,8 +223,11 @@ let file_resolver =
       let build_dir = Coq_elpi_config.elpi_dir in
       let installed_dirs =
         let valid_dir d = try Sys.is_directory d with Sys_error _ -> false in
-        let env = Boot.Env.init () in
-        let user_contrib = Boot.Env.(user_contrib env |> Path.to_string) in
+        let user_contrib =
+          if Sys.backend_type = Sys.Other "js_of_ocaml" then "../.."
+          else
+            let env = Boot.Env.init () in
+            Boot.Env.(user_contrib env |> Path.to_string) in
         user_contrib :: Envars.coqpath
         |> List.map (fun p -> p ^ "/elpi/")
         |> ((@) [".";".."]) (* Hem, this sucks *)
@@ -296,7 +299,7 @@ let append_to_prog name nature l =
 
 let in_program : qualified_name * nature option * src list -> Libobject.obj =
   let open Libobject in
-  declare_object @@ global_object_nodischarge "ELPI"
+  declare_object @@ superglobal_object_nodischarge "ELPI"
     ~cache:(fun (name,nature,src_ast) ->
       program_src :=
         SLMap.add name (append_to_prog name nature src_ast) !program_src)
@@ -693,7 +696,7 @@ let run_program loc name ~atts args =
   in
   let query ~depth state =
     let state, args, gls = EU.map_acc
-      (Coq_elpi_arg_HOAS.in_elpi_cmd ~depth ~raw:raw_args Coq_elpi_HOAS.(mk_coq_context ~options:default_options state))
+      (Coq_elpi_arg_HOAS.in_elpi_cmd ~depth ~raw:raw_args Coq_elpi_HOAS.(mk_coq_context ~options:(default_options ()) state))
       state args in
     let state, q = atts2impl loc ~depth state atts (ET.mkApp mainc (EU.list_to_lp_list args) []) in
     let state = API.State.set Coq_elpi_builtins.tactic_mode state false in
